@@ -13,8 +13,8 @@ thermind <- function(t){
   C1 <- 5 * (Am - 18)
   C2 <- 10 * (Am - 21)
   C3 <- 5 * (Am - 27)
-  C4 <- 10 * (Am - 46)
-  if(Am < 9) Itc <- It - 90
+  C4 <- 20 * (Am - 46)
+  if(Am < 9) Itc <- It - 90 + 10 * Am
   if(Am >= 9 & Am <= 18) Itc <- It
   if(Am > 18) Itc <- It + C1 + C2 + C3 + C4
   Itc
